@@ -117,13 +117,15 @@ def from_splitted_env(name: str, separator: str) -> list[str] | None:
     return [v.strip() for v in value.split(separator) if v.strip()] or None
 
 
-verbose_option = Option(
+verbose_option = ArgumentGroup("Verbosity options", is_mutually_exclusive=True)
+verbose_option.add_argument(
     "-v",
     "--verbose",
     action="count",
     default=0,
     help="Use `-v` for detailed output and `-vv` for more detailed",
 )
+verbose_option.add_argument("-q", "--quiet", action="store_const", const=-1, dest="verbose", help="Suppress output")
 
 
 dry_run_option = Option(
@@ -185,7 +187,7 @@ def no_isolation_option(project: Project, namespace: argparse.Namespace, values:
 
 install_group.options.append(no_isolation_option)
 
-groups_group = ArgumentGroup("Dependencies selection")
+groups_group = ArgumentGroup("Dependencies Selection")
 groups_group.add_argument(
     "-G",
     "--group",
@@ -361,3 +363,36 @@ venv_option = Option(
     help="Run the command in the virtual environment with the given key. [env var: PDM_IN_VENV]",
     default=os.getenv("PDM_IN_VENV"),
 )
+
+
+lock_strategy_group = ArgumentGroup("Lock Strategy")
+lock_strategy_group.add_argument(
+    "--strategy",
+    "-S",
+    dest="strategy_change",
+    metavar="STRATEGY",
+    action=split_lists(","),
+    help="Specify lock strategy (cross_platform, static_urls, direct_minimal_versions). Add 'no_' prefix to disable."
+    " Can be supplied multiple times or split by comma.",
+)
+lock_strategy_group.add_argument(
+    "--no-cross-platform",
+    action="append_const",
+    dest="strategy_change",
+    const="no_cross_platform",
+    help="[DEPRECATED] Only lock packages for the current platform",
+)
+lock_strategy_group.add_argument(
+    "--static-urls",
+    action="append_const",
+    dest="strategy_change",
+    help="[DEPRECATED] Store static file URLs in the lockfile",
+    const="static_urls",
+)
+lock_strategy_group.add_argument(
+    "--no-static-urls",
+    action="append_const",
+    dest="strategy_change",
+    help="[DEPRECATED] Do not store static file URLs in the lockfile",
+    const="no_static_urls",
+)
