@@ -73,8 +73,7 @@ def _is_namespace_package(root: str) -> bool:
 
 
 def _create_symlinks_recursively(source: str, destination: str) -> Iterable[str]:
-    """Create symlinks recursively from source to destination.
-    Caveats: This don't work for pkgutil or pkg_resources namespace packages.
+    """Create symlinks recursively from source to destination. In the following ways:
     package  <-- link
         __init__.py
     namespace_package  <-- mkdir
@@ -169,7 +168,7 @@ class InstallDestination(SchemeDictionaryDestination):
         return super().finalize_installation(scheme, record_file_path, records)
 
 
-def install_wheel(wheel: str, environment: BaseEnvironment, direct_url: dict[str, Any] | None = None) -> None:
+def install_wheel(wheel: str, environment: BaseEnvironment, direct_url: dict[str, Any] | None = None) -> str:
     """Install a normal wheel file into the environment."""
     additional_metadata = None
     if direct_url is not None:
@@ -179,12 +178,10 @@ def install_wheel(wheel: str, environment: BaseEnvironment, direct_url: dict[str
         interpreter=str(environment.interpreter.executable),
         script_kind=_get_kind(environment),
     )
-    _install_wheel(wheel=wheel, destination=destination, additional_metadata=additional_metadata)
+    return _install_wheel(wheel=wheel, destination=destination, additional_metadata=additional_metadata)
 
 
-def install_wheel_with_cache(
-    wheel: str, environment: BaseEnvironment, direct_url: dict[str, Any] | None = None
-) -> None:
+def install_wheel_with_cache(wheel: str, environment: BaseEnvironment, direct_url: dict[str, Any] | None = None) -> str:
     """Only create .pth files referring to the cached package.
     If the cache doesn't exist, create one.
     """
@@ -246,6 +243,7 @@ def install_wheel_with_cache(
         additional_metadata=additional_metadata,
     )
     package_cache.add_referrer(dist_info_dir)
+    return dist_info_dir
 
 
 def _install_wheel(
