@@ -175,6 +175,16 @@ class Candidate:
     def identify(self) -> str:
         return self.req.identify()
 
+    def copy_with(self, requirement: Requirement) -> Candidate:
+        can = Candidate(requirement, name=self.name, version=self.version, link=self.link)
+        can.summary = self.summary
+        can.hashes = self.hashes
+        can._requires_python = self._requires_python
+        can._prepared = self._prepared
+        if can._prepared:
+            can._prepared.req = requirement
+        return can
+
     @property
     def dep_key(self) -> tuple[str, str | None]:
         """Key for retrieving and storing dependencies from the provider.
@@ -601,7 +611,9 @@ class PreparedCandidate:
         """Get the dependencies of a candidate from metadata."""
         extras = self.req.extras or ()
         return filter_requirements_with_extras(
-            self.req.project_name, self.metadata.requires or [], extras  # type: ignore[arg-type]
+            self.req.project_name,  # type: ignore[arg-type]
+            self.metadata.requires or [],
+            extras,
         )
 
     def should_cache(self) -> bool:
