@@ -234,7 +234,9 @@ class BaseRepository:
         if not applicable_cans and allow_prereleases is None:
             # No non-pre-releases is found, force pre-releases now
             applicable_cans = LazySequence(
-                c for c in cans if requirement.specifier.contains(c.version, True)  # type: ignore[arg-type, union-attr]
+                c
+                for c in cans
+                if requirement.specifier.contains(c.version, True)  # type: ignore[arg-type, union-attr]
             )
             applicable_cans_python_compatible = LazySequence(filter_candidates_with_requires_python(applicable_cans))
             if applicable_cans_python_compatible:
@@ -342,9 +344,7 @@ class BaseRepository:
         of a given package version.
         """
         if (
-            candidate.req.is_vcs
-            or candidate.req.is_file_or_url
-            and candidate.req.is_local_dir  # type: ignore[attr-defined]
+            candidate.req.is_vcs or candidate.req.is_file_or_url and candidate.req.is_local_dir  # type: ignore[attr-defined]
         ):
             return []
         if candidate.hashes:
@@ -552,7 +552,14 @@ class LockedRepository(BaseRepository):
         )
 
     def _get_dependencies_from_lockfile(self, candidate: Candidate) -> CandidateInfo:
-        return self.candidate_info[self._identify_candidate(candidate)]
+        err = (
+            f"Missing package {candidate.identify()} from the lockfile, "
+            "the lockfile may be broken. Run `pdm update` to fix it."
+        )
+        try:
+            return self.candidate_info[self._identify_candidate(candidate)]
+        except KeyError as e:  # pragma: no cover
+            raise CandidateNotFound(err) from e
 
     def dependency_generators(self) -> Iterable[Callable[[Candidate], CandidateInfo]]:
         return (
@@ -601,8 +608,7 @@ class LockedRepository(BaseRepository):
             if not requirement.name:
                 # make sure can.identify() won't return a randomly-generated name
                 requirement.name = can.name
-            can.req = requirement
-            yield can
+            yield can.copy_with(requirement)
 
     def get_hashes(self, candidate: Candidate) -> list[FileHash]:
         return candidate.hashes
