@@ -145,12 +145,11 @@ class Requirement:
             try:
                 kwargs["marker"] = get_marker(kwargs["marker"])
             except InvalidMarker as e:
-                raise RequirementError("Invalid marker: %s" % str(e)) from None
+                raise RequirementError(f"Invalid marker: {e}") from None
         if "extras" in kwargs and isinstance(kwargs["extras"], str):
             kwargs["extras"] = tuple(e.strip() for e in kwargs["extras"][1:-1].split(","))
-        version = kwargs.pop("version", None)
-        if version:
-            kwargs["specifier"] = get_specifier(version)
+        version = kwargs.pop("version", "")
+        kwargs["specifier"] = get_specifier(version)
         return cls(**{k: v for k, v in kwargs.items() if k in inspect.signature(cls).parameters})
 
     @classmethod
@@ -240,7 +239,7 @@ class Requirement:
 class NamedRequirement(Requirement):
     def as_line(self) -> str:
         extras = f"[{','.join(sorted(self.extras))}]" if self.extras else ""
-        return f"{self.project_name}{extras}{self.specifier}{self._format_marker()}"
+        return f"{self.project_name}{extras}{self.specifier or ''}{self._format_marker()}"
 
 
 @dataclasses.dataclass(eq=False)
@@ -332,7 +331,10 @@ class FileRequirement(Requirement):
             return
         # self.path is relative
         self.path = path_without_fragments(os.path.relpath(self.path, backend.root))
-        self.url = backend.relative_path_to_url(self.path.as_posix())
+        path = self.path.as_posix()
+        if path == ".":
+            path = ""
+        self.url = backend.relative_path_to_url(path)
 
     @property
     def is_local(self) -> bool:
@@ -442,6 +444,7 @@ def filter_requirements_with_extras(
     If extras are given, return those with matching extra markers.
     Otherwise, return those without extra markers.
     """
+    extras = [normalize_name(e) for e in extras]
     result: list[str] = []
     extras_in_meta: set[str] = set()
     for req in requirement_lines:
@@ -494,10 +497,10 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
         except InvalidRequirement as e:
             m = _file_req_re.match(line)
             if m is None:
-                raise RequirementError(str(e)) from None
+                raise RequirementError(f"{line}: {e}") from None
             args = m.groupdict()
             if not line.startswith(".") and not args["url"] and args["path"] and not os.path.exists(args["path"]):
-                raise RequirementError(str(e)) from None
+                raise RequirementError(f"{line}: {e}") from None
             r = FileRequirement.create(**args)
         else:
             r = Requirement.from_pkg_requirement(pkg_req)
@@ -511,5 +514,5 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
             assert isinstance(r, FileRequirement)
             r.editable = True
         else:
-            raise RequirementError("Editable requirement is only supported for VCS link or local directory.")
+            raise RequirementError(f"{line}: Editable requirement is only supported for VCS link or local directory.")
     return r
