@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Dict, cast
 
+from pdm import termui
 from pdm.models.candidates import Candidate
 from pdm.models.repositories import BaseRepository
 from pdm.models.requirements import strip_extras
@@ -32,9 +33,17 @@ def resolve(
     requirements.append(PythonRequirement.from_pyspec_set(requires_python))
     provider = cast(BaseProvider, resolver.provider)
     repository = cast(BaseRepository, provider.repository)
-
     result = resolver.resolve(requirements, max_rounds)
 
+    if repository.has_warnings:
+        repository.environment.project.core.ui.echo(
+            "Use `-q/--quiet` to suppress these warnings, or ignore them per-package with "
+            r"`ignore_package_warnings` config in \[tool.pdm] table.",
+            err=True,
+            style="info",
+            verbosity=termui.Verbosity.NORMAL,
+        )
+
     mapping = cast(Dict[str, Candidate], result.mapping)
     mapping.pop("python", None)
 
